
/*****************************************************************************/
/* This is the stata do file we used to produce the accompanying excel */
/* file. The purpose of the file is to make tables of means and */
/* standard deviations using as original source the data in the file */
/* IPUMS-non-NA-or-occ1950.dta */
/* The file IPUMS-non-NA-or-occ1950.dta is taken from IPUMS with */
/* household income year and sector variables, omitting NA observations */
/* author: Delia Grigg for Federico Echenique and Jon Eguia. */
/*****************************************************************************/

/* set delimiter */
#delimit;

/* start log file */
log using maketables, replace text;

/* read in data */
use /tmp/cohesion/IPUMS-non-NA-or-occ1950.dta;

/* drop unnecessary variables */
keep year serial hhincome ind1950;

/* detrend data */
/* first, generate variable that is mean of hhincome, incbar */
egen incbar = mean(hhincome);

/* second, generate mean of hhincome by year */
egen meanincp = mean(hhincome), by (year);

/* generate deflated data  */
g incdefl = hhincome / meaninc ;

/* save data */
save IPUMS-tables2, replace;

/* compute mean incprime2 (hhincome detrended) by (year, sector) */
collapse (mean) meaninc=incdefl (sd) sdinc=incdefl (count) countinc=incdefl , by(year ind1950) fast;

/* calculate coefficient of variation */
g coefvar = sdinc / meaninc ;

/* export to tab delimited file */
outsheet using means.txt;

/* save data */
save IPUMS-tables-collapsed, replace;

/* clear memory */
clear;

/* close log file */
log close;

